==> james-project-3.4.0-source-release.zip: james-project-3.4.0/server/data/data-jmap/src/main/java/org/apache/james/jmap/api/filtering/FilteringManagement.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.jmap.api.filtering;

import java.util.Arrays;
import java.util.List;

import org.apache.james.core.User;

import com.google.common.collect.ImmutableList;

public interface FilteringManagement {

    void defineRulesForUser(User user, List<Rule> rules);

    default void defineRulesForUser(User user, Rule... rules) {
        defineRulesForUser(user, Arrays.asList(rules));
    }

    default void clearRulesForUser(User user) {
        defineRulesForUser(user, ImmutableList.of());
    }

    List<Rule> listRulesForUser(User user);

}

==> james-project-3.5.0-source-release.zip: james-project-3.5.0/server/data/data-jmap/src/main/java/org/apache/james/jmap/api/filtering/FilteringManagement.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.jmap.api.filtering;

import java.util.Arrays;
import java.util.List;

import org.apache.james.core.Username;

import com.google.common.collect.ImmutableList;

public interface FilteringManagement {

    void defineRulesForUser(Username username, List<Rule> rules);

    default void defineRulesForUser(Username username, Rule... rules) {
        defineRulesForUser(username, Arrays.asList(rules));
    }

    default void clearRulesForUser(Username username) {
        defineRulesForUser(username, ImmutableList.of());
    }

    List<Rule> listRulesForUser(Username username);

}
